@@ -29,6 +29,8 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <locale.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 typedef enum {
   LOAD_SCHEMA_FILE,
@@ -156,7 +158,7 @@ struct poptOption options[] = {
     POPT_ARG_NONE,
     &dump_values,
     0,
-    N_("Dump to standard out an XML description of all entries under a dir, recursively."),
+    N_("Dump to standard output an XML description of all entries under a directory, recursively."),
     NULL
   },
   {
@@ -165,7 +167,7 @@ struct poptOption options[] = {
     POPT_ARG_STRING,
     &entry_file,
     0,
-    N_("Load from the specified file an XML description of values and set them relative to a dir."),
+    N_("Load from the specified file an XML description of values and set them relative to a directory."),
     NULL
   },
   {
@@ -183,7 +185,7 @@ struct poptOption options[] = {
     POPT_ARG_NONE,
     &recursive_list,
     0,
-    N_("Print all subdirectories and entries under a dir, recursively."),
+    N_("Print all subdirectories and entries under a directory, recursively."),
     NULL
   },
   { 
@@ -460,8 +462,7 @@ struct poptOption options[] = {
 
 static int do_break_key(GConfEngine* conf, const gchar** args);
 static int do_break_directory(GConfEngine* conf, const gchar** args);
-static int do_makefile_install(GConfEngine* conf, const gchar** args);
-static int do_makefile_uninstall(GConfEngine* conf, const gchar** args);
+static int do_makefile_install(GConfEngine* conf, const gchar** args, gboolean unload);
 static int do_recursive_list(GConfEngine* conf, const gchar** args);
 static int do_dump_values(GConfEngine* conf, const gchar** args);
 static int do_all_pairs(GConfEngine* conf, const gchar** args);
@@ -888,7 +889,10 @@ main (int argc, char** argv)
   if (makefile_install_mode)
     {
       const gchar** args = poptGetArgs(ctx);
-      gint retval = do_makefile_install (conf, args);
+      gint retval;
+
+      umask (022);
+      retval = do_makefile_install (conf, args, FALSE);
       
       gconf_engine_unref (conf);
 
@@ -898,7 +902,10 @@ main (int argc, char** argv)
   if (makefile_uninstall_mode)
     {
       const gchar** args = poptGetArgs(ctx);
-      gint retval = do_makefile_uninstall (conf, args);
+      gint retval;
+
+      umask (022);
+      retval = do_makefile_install (conf, args, TRUE);
       
       gconf_engine_unref (conf);
 
@@ -3381,7 +3388,7 @@ process_key_list(GConfEngine* conf, gboolean unload, const gchar* schema_name, G
     {
       GError* error = NULL;
 
-      if (!gconf_engine_associate_schema(conf, tmp->data, unload ? schema_name : NULL, &error))
+      if (!gconf_engine_associate_schema(conf, tmp->data, !unload ? schema_name : NULL, &error))
         {
           g_assert(error != NULL);
           
@@ -3708,7 +3715,7 @@ do_load_file(GConfEngine* conf, LoadType load_type, gboolean unload, const gchar
 }
 
 static int
-do_makefile_install(GConfEngine* conf, const gchar** args)
+do_makefile_install(GConfEngine* conf, const gchar** args, gboolean unload)
 {
   GError* err = NULL;
   
@@ -3720,39 +3727,7 @@ do_makefile_install(GConfEngine* conf, const gchar** args)
 
   while (*args)
     {
-      if (do_load_file(conf, LOAD_SCHEMA_FILE, FALSE, *args, NULL) != 0)
-        return 1;
-
-      ++args;
-    }
-
-  gconf_engine_suggest_sync(conf, &err);
-
-  if (err != NULL)
-    {
-      g_printerr (_("Error syncing config data: %s"),
-		  err->message);
-      g_error_free(err);
-      return 1;
-    }
-  
-  return 0;
-}
-
-static int
-do_makefile_uninstall(GConfEngine* conf, const gchar** args)
-{
-  GError* err = NULL;
-  
-  if (args == NULL)
-    {
-      g_printerr (_("Must specify some schema files to uninstall\n"));
-      return 1;
-    }
-
-  while (*args)
-    {
-      if (do_load_file(conf, LOAD_SCHEMA_FILE, TRUE, *args, NULL) != 0)
+      if (do_load_file(conf, LOAD_SCHEMA_FILE, unload, *args, NULL) != 0)
         return 1;
 
       ++args;
